@@ -16,6 +16,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <cstring>
 #include <gtkmm/stock.h>
 #include <obby/format_string.hpp>
 
@@ -23,6 +24,12 @@
 #include "header.hpp"
 #include "icon.hpp"
 
+#include "features.hpp"
+
+#ifdef OSX_NATIVE
+#include <ige-mac-menu.h>
+#endif
+
 namespace {
 	Glib::ustring ui_desc = 
 		"<ui>"
@@ -612,10 +619,14 @@ Gobby::Header::Header(const ApplicationState& state,
 #ifdef WITH_GTKSOURCEVIEW2
 	GSList* lang_list = NULL;
 	const gchar* const* ids = gtk_source_language_manager_get_language_ids(lang_mgr);
-	for(const gchar* const* id = ids; *id != NULL; ++ id)
+	if(ids != NULL)
 	{
-		GtkSourceLanguage* language = gtk_source_language_manager_get_language(lang_mgr, *id);
-		lang_list = g_slist_prepend(lang_list, language);
+		for(const gchar* const* id = ids; *id != NULL; ++ id)
+		{
+			GtkSourceLanguage* language = gtk_source_language_manager_get_language(lang_mgr, *id);
+			if(!gtk_source_language_get_hidden(language))
+				lang_list = g_slist_prepend(lang_list, language);
+		}
 	}
 #else
 	const GSList* list = gtk_source_languages_manager_get_available_languages(
@@ -711,8 +722,24 @@ Gobby::Header::Header(const ApplicationState& state,
 			"XML UI definition lacks toolbar"
 		);
 	}
+#ifdef OSX_NATIVE
+	ige_mac_menu_set_menu_bar(GTK_MENU_SHELL (m_menubar->gobj()));
+	
+	ige_mac_menu_set_quit_menu_item(GTK_MENU_ITEM (
+		m_ui_manager->get_widget("/MenuMainBar/MenuApp/AppQuit")->gobj()));
+	
+	ige_mac_menu_add_app_menu_item(ige_mac_menu_add_app_menu_group (),
+	                                   GTK_MENU_ITEM (
+		m_ui_manager->get_widget("/MenuMainBar/MenuHelp/HelpAbout")->gobj()),
+	                                   NULL);
 
+	 ige_mac_menu_add_app_menu_item(ige_mac_menu_add_app_menu_group (),
+	                                   GTK_MENU_ITEM (
+		m_ui_manager->get_widget("/MenuMainBar/MenuEdit/EditPreferences")->gobj()),
+	                                   NULL);
+#else
 	pack_start(*m_menubar, Gtk::PACK_SHRINK);
+#endif
 	pack_start(*m_toolbar, Gtk::PACK_SHRINK);
 }
 
