@@ -59,9 +59,11 @@ Gobby::LogView::LogView():
 	);
 
 	set_editable(false);
-	set_cursor_visible(false);
 	set_wrap_mode(Gtk::WRAP_WORD_CHAR);
 
+	// needed for accessibility
+	set_cursor_visible(true);
+
 #ifdef HAVE_SHOW_URL
 	signal_motion_notify_event().connect(
 		sigc::mem_fun(*this, &LogView::on_motion_notify)
