@@ -517,7 +517,7 @@ void Gobby::Window::on_about()
 	dlg.set_comments(_("A collaborative text editor"));
 
 	dlg.set_copyright(
-		"Copyright (C) 2005-2007 0x539 dev group <crew@0x539.de>"
+		"Copyright (C) 2005-2008 0x539 dev group <crew@0x539.de>"
 	);
 
 	dlg.set_logo(m_icon_mgr.gobby);
@@ -541,23 +541,6 @@ void Gobby::Window::on_about()
 	dlg.set_authors(authors);
 	dlg.set_artists(artists);
 
-	dlg.set_translator_credits(
-		"French translation:\n"
-		"  Peer Janssen <peer@baden-online.de>\n"
-		"  Mohammed Adnene Trojette <adn@diwi.org>\n"
-		"\n"
-		"Spanish translation:\n"
-		"  Mario Palomo Torrero <mpalomo@ihman.com>\n"
-		"\n"
-		"Swedish translation:\n"
-		"  Daniel Nylander <po@danielnylander.se>\n"
-		"\n"
-		"German translation:\n"
-		"  Philipp Kern <phil@0x539.de>\n"
-		"  Armin Burgmeier <armin@0x539.de>\n"
-		"  Thomas Glatt <tom@0x539.de>\n"
-		);
-
 	dlg.set_license(
 		"This program is free software; you can redistribute it\n"
 		"and/or modify it under the terms of the GNU General Public\n"
@@ -1255,10 +1238,11 @@ bool Gobby::Window::session_join(bool initial_dialog)
 		// Read settings
 		Glib::ustring host = m_join_dlg->get_host();
 		unsigned int port = m_join_dlg->get_port();
+		const net6::address* addr = m_join_dlg->get_address();
 		Glib::ustring name = m_join_dlg->get_name();
 		Gdk::Color color = m_join_dlg->get_color();
 
-		if(session_join_impl(host, port, name, color) )
+		if(session_join_impl(host, port, addr, name, color) )
 			break;
 		else
 			response = m_join_dlg->run();
@@ -1320,6 +1304,7 @@ bool Gobby::Window::session_open(bool initial_dialog)
 
 bool Gobby::Window::session_join_impl(const Glib::ustring& host,
                                       unsigned int port,
+				      const net6::address* addr,
                                       const Glib::ustring& name,
                                       const Gdk::Color& color)
 {
@@ -1328,6 +1313,7 @@ bool Gobby::Window::session_join_impl(const Glib::ustring& host,
 		m_config.get_root()["session"],
 		host,
 		port,
+		addr,
 		name,
 		color
 	);
